Draws the posterior median and credible band of the survival function for each group. Requires `ggplot2`.
Usage
# S3 method for class 'survival_exnex'
plot(x, ...)Draws the posterior median and credible band of the survival function for each group. Requires `ggplot2`.
# S3 method for class 'survival_exnex'
plot(x, ...)