Prints a compact summary and optionally traceplots of posterior draws.
Usage
# S3 method for class 'exnex_surv'
print(x, show_trace = TRUE, parameters = NULL, max_parameters = Inf, ...)Prints a compact summary and optionally traceplots of posterior draws.
# S3 method for class 'exnex_surv'
print(x, show_trace = TRUE, parameters = NULL, max_parameters = Inf, ...)